@@ -1,5 +1,5 @@
 package Git::Database::Backend::Git::Repository;
-$Git::Database::Backend::Git::Repository::VERSION = '0.011';
+$Git::Database::Backend::Git::Repository::VERSION = '0.012';
 use IO::Select;
 use Sub::Quote;
 
@@ -102,6 +102,9 @@ sub get_object_attributes {
     # object does not exist in the git object database
     return undef if $parts[-1] eq 'missing';
 
+    # git versions >= 2.21.0.rc0 explicitely say if a sha1 is ambiguous
+    return undef if $kind eq 'ambiguous';
+
     # read the whole content in memory at once
     my $res = read $out, (my $content), $size;
     if( $res != $size ) {
@@ -211,7 +214,7 @@ Git::Database::Backend::Git::Repository - A Git::Database backend based on Git::
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -242,7 +245,7 @@ Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2016-2017 Philippe Bruhat (BooK), all rights reserved.
+Copyright 2016-2019 Philippe Bruhat (BooK), all rights reserved.
 
 =head1 LICENSE
 
